@@ -6,6 +6,14 @@
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, see <https://www.gnu.org/licenses/>.
+ *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
@@ -41,7 +49,6 @@
 #endif
 
 /* prototypes referenced in data.h */
-static void find_referral_server_6bone(char **, const char *);
 static void find_referral_server_apnic(char **, const char *);
 static void find_referral_server_arin(char **, const char *);
 static void find_referral_server_iana(char **, const char *);
